# -*- coding: iso-8859-15 -*-
irregulars_dictionary = {
    'ir':{
        'indicitive':{
            'present':{
                'yo':'voy',
                'tu':'vas',
                'usted':'va',
                'nosotros':'vamos',
                'vosotros':'vais',
                'ustedes':'van'
            },
            'imperfect':{
                'yo':'iba',
                'tu':'ibas',
                'usted':'iba',
                'nosotros':'íbamos',
                'vosotros':'ibais',
                'ustedes':'iban'
            },
            'preterite':{
                'yo':'fui',
                'tu':'fuiste',
                'usted':'fue',
                'nosotros':'fuimos',
                'vosotros':'fuisteis',
                'ustedes':'fueron'
            }
        }
    },
    'ser':{
        'indicitive':{
            'present':{
                'yo':'soy',
                'tu':'eres',
                'usted':'es',
                'nosotros':'somos',
                'vosotros':'sois',
                'ustedes':'son'    
            },
            'imperfect':{
                'yo':'era',
                'tu':'eras',
                'usted':'era',
                'nosotros':'éramos',
                'vosotros':'erais',
                'ustedes':'eran'    
            },
            'preterite':{
                'yo':'fui',
                'tu':'fuiste',
                'usted':'fue',
                'nosotros':'fuimos',
                'vosotros':'fuisteis',
                'ustedes':'fueron'
            }
        }
    },
    'ver':{
        'indicitive':{
            'imperfect':{
                'yo':'veía',
                'tu':'veías',
                'usted':'veía',
                'nosotros':'veíamos',
                'vosotros':'veíais',
                'ustedes':'veían'
            }
        }
    },
}


from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='spanishconjugator',
    version='2.1.9',
    description='A python library to conjugate spanish words with parameters tense, mood and pronoun',
    packages=['spanishconjugator','spanishconjugator.tenses','spanishconjugator.irregulars'],
    package_dir={'spanishconjugator': 'src/spanishconjugator'},
    classifiers = [
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Operating System :: OS Independent"
    ],
    long_description=long_description,
    long_description_content_type="text/markdown",
    extras_require={
        "dev": [
            "pytest>=6.0.1",
            "check-manifest>=0.42",
            "twine>=3.2.0"
        ],
    },
    url="https://github.com/Benedict-Carling/spanish-conjugator",
    author="Benedict Carling",
    author_email="bencarling1@gmail.com"
)


# -*- coding: iso-8859-15 -*-
from .tenses.indicitive.preterite import indicitive_preterite
from .tenses.indicitive.present import indicitive_present
from .tenses.indicitive.imperfect import indicitive_imperfect
from .tenses.indicitive.future import indicitive_future
from .tenses.indicitive.present_perfect import indicitive_present_perfect
from .tenses.indicitive.past_perfect import indicitive_past_perfect
# ------------------- Irregulars ------------------
from .irregulars.irregular_dict import irregulars_dictionary

# ----------------- Conjugator --------------------

class Conjugator():

    def conjugate(self,root_verb,tense,mood,pronoun):
        tense = tense.lower()
        mood = mood.lower()
        pronoun = pronoun.lower()

# ----------------------------------- Present Indicitive ----------------------------------- #

        if tense == "present":
            if mood == "indicitive":
                try:
                    conjugation = irregulars_dictionary[root_verb][mood][tense][pronoun]
                except:
                    conjugation = indicitive_present(root_verb, pronoun)
                return conjugation

# ----------------------------------- Imperfect Indicitive ----------------------------------- #

        if tense == "imperfect":
            if mood == "indicitive":
                try:
                    conjugation = irregulars_dictionary[root_verb][mood][tense][pronoun]
                except:
                    conjugation = indicitive_imperfect(root_verb, pronoun)
                return conjugation

# ----------------------------------- Preterite Indicitive ----------------------------------- #
        if tense == "preterite":
            if mood == "indicitive":
                try:
                    conjugation = irregulars_dictionary[root_verb][mood][tense][pronoun]
                except:
                    conjugation = indicitive_preterite(root_verb, pronoun)
                return conjugation

# ----------------------------------- Future Simple Indicitive ----------------------------------- #
        if tense == "future":
            if mood == "indicitive":
                try:
                    conjugation = irregulars_dictionary[root_verb][mood][tense][pronoun]
                except:
                    conjugation = indicitive_future(root_verb, pronoun)
                return conjugation
                
# ----------------------------------- Present Perfect Compound Tense ----------------------------- #
        if tense == "present_perfect":
            if mood == "indicitive":
                try:
                    conjugation = irregulars_dictionary[root_verb][mood][tense][pronoun]
                except:
                    conjugation = indicitive_present_perfect(root_verb, pronoun)
                return conjugation
                
# ----------------------------------- Past Perfect Compound Tense ----------------------------- #

        if tense == "past_perfect":
            if mood == "indicitive":
                try:
                    conjugation = irregulars_dictionary[root_verb][mood][tense][pronoun]
                except:
                    conjugation = indicitive_past_perfect(root_verb, pronoun)
                return conjugation
            
# ----------------------------------- Catch missed conjugations
        return "Error - verb not found"